@@ -1,12 +1,12 @@
 /*
-**  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2007-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-ar.c,v 1.25 2008/05/22 06:29:14 msk Exp $
+**  $Id: dkim-ar.c,v 1.27 2009/04/26 04:44:54 msk Exp $
 */
 
 #ifndef lint
-static char dkim_ar_c_id[] = "@(#)$Id: dkim-ar.c,v 1.25 2008/05/22 06:29:14 msk Exp $";
+static char dkim_ar_c_id[] = "@(#)$Id: dkim-ar.c,v 1.27 2009/04/26 04:44:54 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -44,11 +44,11 @@ struct lookup methods[] =
 {
 	{ "auth",		ARES_METHOD_AUTH },
 	{ "dkim",		ARES_METHOD_DKIM },
-	{ "dkim-ssp",		ARES_METHOD_DKIMSSP },
 	{ "domainkeys",		ARES_METHOD_DOMAINKEYS },
 	{ "iprev",		ARES_METHOD_IPREV },
-	{ "senderid",		ARES_METHOD_SENDERID },
+	{ "sender-id",		ARES_METHOD_SENDERID },
 	{ "spf",		ARES_METHOD_SPF },
+	{ "x-dkim-adsp",	ARES_METHOD_DKIMADSP },
 	{ NULL,			ARES_METHOD_UNKNOWN }
 };
 
