@@ -1,15 +1,15 @@
 /*
-**  Copyright (c) 2006-2008 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2006-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-config.h,v 1.74 2008/12/24 20:41:48 msk Exp $
+**  $Id: dkim-config.h,v 1.75 2009/05/27 16:34:05 msk Exp $
 */
 
 #ifndef _DKIM_CONFIG_H_
 #define _DKIM_CONFIG_H_
 
 #ifndef lint
-static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.74 2008/12/24 20:41:48 msk Exp $";
+static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.75 2009/05/27 16:34:05 msk Exp $";
 #endif /* !lint */
 
 struct configdef dkimf_config[] =
@@ -110,6 +110,9 @@ struct configdef dkimf_config[] =
 	{ "SelectorHeader",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_SELECTOR_HEADER */
 	{ "SendADSPReports",		CONFIG_TYPE_BOOLEAN,	FALSE },
+#ifdef _FFR_SENDER_HEADERS
+	{ "SenderHeaders",		CONFIG_TYPE_STRING,	FALSE },
+#endif /* _FFR_SENDER_HEADERS */
 	{ "SendReports",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "SignatureAlgorithm",		CONFIG_TYPE_STRING,	FALSE },
 	{ "SignatureTTL",		CONFIG_TYPE_INTEGER,	FALSE },
