@@ -2,11 +2,11 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: util.c,v 1.87 2009/02/09 19:42:59 msk Exp $
+**  $Id: util.c,v 1.88 2009/05/27 16:34:05 msk Exp $
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.87 2009/02/09 19:42:59 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.88 2009/05/27 16:34:05 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -126,6 +126,10 @@ static char *optlist[] =
 	"_FFR_SELECTOR_HEADER",
 #endif /* _FFR_SELECTOR_HEADER */
 
+#if _FFR_SENDER_HEADERS
+	"_FFR_SENDER_HEADERS",
+#endif /* _FFR_SENDER_HEADERS */
+
 #if _FFR_STATS
 	"_FFR_STATS",
 #endif /* _FFR_STATS */
