@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char ar_c_id[] = "@(#)$Id: ar.c,v 1.78 2009/02/14 09:08:12 msk Exp $";
+static char ar_c_id[] = "@(#)$Id: ar.c,v 1.81 2009/03/24 17:01:11 msk Exp $";
 #endif /* !lint */
 
 /* OS stuff */
@@ -15,9 +15,9 @@ static char ar_c_id[] = "@(#)$Id: ar.c,v 1.78 2009/02/14 09:08:12 msk Exp $";
 /* system includes */
 #include <sys/param.h>
 #include <sys/types.h>
-#ifdef SOLARIS
+#if SOLARIS > 20700
 # include <iso/limits_iso.h>
-#endif /* SOLARIS */
+#endif /* SOLARIS > 20700 */
 #include <sys/socket.h>
 #include <sys/time.h>
 #include <sys/uio.h>
@@ -103,7 +103,7 @@ struct ar_query
 #ifdef AF_INET6
 typedef struct sockaddr_storage SOCKADDR;
 #else /* AF_INET6 */
-typedef struct sockaddr_in SOCKADDR;
+typedef struct sockaddr SOCKADDR;
 #endif /* AF_INET6 */
 
 struct ar_libhandle
@@ -176,7 +176,7 @@ ar_malloc(AR_LIB lib, size_t bytes)
 	assert(lib != NULL);
 
 	if (lib->ar_malloc != NULL)
-		return ar_malloc(lib->ar_closure, bytes);
+		return lib->ar_malloc(lib->ar_closure, bytes);
 	else
 		return malloc(bytes);
 }
@@ -199,7 +199,7 @@ ar_free(AR_LIB lib, void *ptr)
 	assert(ptr != NULL);
 
 	if (lib->ar_free != NULL)
-		ar_free(lib->ar_closure, ptr);
+		lib->ar_free(lib->ar_closure, ptr);
 	else
 		free(ptr);
 }
@@ -1218,6 +1218,9 @@ ar_dispatcher(void *tp)
 static int
 ar_res_init(AR_LIB new)
 {
+#if !defined(AR_RES_MANUAL) && !defined(AF_INET6)
+	int c;
+#endif /* !defined(AR_RES_MANUAL) && !defined(AF_INET6) */
 	size_t bytes;
 	SOCKADDR *sa;
 
@@ -1270,13 +1273,13 @@ ar_res_init(AR_LIB new)
 	ar_res_parse(&new->ar_nscount, new->ar_nsaddrs,
 	             &new->ar_retries, &new->ar_retry.tv_sec);
 #else /* defined(AR_RES_MANUAL) || defined(AF_INET6) */
-	memcpy(new->ar_nsaddrs, ar_res.nsaddr_list,
-	       sizeof(SOCKADDR) * ar_res.nscount);
+	memcpy(new->ar_nsaddrs, &new->ar_res.nsaddr_list,
+	       sizeof(SOCKADDR) * new->ar_res.nscount);
 
 	/* an address of 0 (INADDR_ANY) should become INADDR_LOOPBACK */
 	for (c = 0; c < new->ar_nscount; c++)
 	{
-		sa = (SOCKADDR *) new->ar_nsaddrs[c];
+		sa = (SOCKADDR *) &new->ar_nsaddrs[c];
 		if (sa->sa_family == AF_INET)
 		{
 			struct sockaddr_in *sin;
