@@ -1,14 +1,15 @@
 /*
-**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char manual_c_id[] = "@(#)$Id: manual.c,v 1.7 2008/02/19 20:16:11 msk Exp $";
+static char manual_c_id[] = "@(#)$Id: manual.c,v 1.8 2009/02/20 00:59:11 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
 #include <sys/types.h>
+#include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <stdio.h>
@@ -31,6 +32,9 @@ static char manual_c_id[] = "@(#)$Id: manual.c,v 1.7 2008/02/19 20:16:11 msk Exp
 #ifndef RES_TIMEOUT
 # define RES_TIMEOUT	5
 #endif /* ! RES_TIMEOUT */
+#ifndef INADDR_NONE
+# define INADDR_NONE	0xffffffff
+#endif /* INADDR_NONE */
 
 #define BUFRSZ		1024
 
@@ -182,12 +186,12 @@ ar_res_parse(int *nscount, struct sockaddr_in *out, int *retry, int *retrans)
 				ns++;
 			}
 #else /* AF_INET6 */
-			addr = inet_addr(p);
-			if (addr == INADDR_NONE)
+			addr.s_addr = inet_addr(p);
+			if (addr.s_addr == INADDR_NONE)
 				continue;
 
 			memcpy(&out[ns].sin_addr.s_addr,
-			       &addr,
+			       &addr.s_addr,
 			       sizeof out[ns].sin_addr.s_addr);
 			out[ns].sin_family = AF_INET;
 			out[ns].sin_port = srv->s_port;
