@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char t_test115_c_id[] = "@(#)$Id: t-test115.c,v 1.4 2008/07/22 20:51:17 msk Exp $";
+static char t_test115_c_id[] = "@(#)$Id: t-test115.c,v 1.6 2009/03/01 06:22:03 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -144,7 +144,7 @@ main(int argc, char **argv)
 	assert(status == DKIM_STAT_OK);
 
 	status = dkim_eoh(dkim);
-	assert(status == DKIM_STAT_NORESOURCE);	/* XXX -- fix this! */
+	assert(status == DKIM_STAT_OK);
 
 	status = dkim_getsiglist(dkim, &sigs, &nsigs);
 	assert(status == DKIM_STAT_OK);
@@ -161,7 +161,7 @@ main(int argc, char **argv)
 	assert(dkim_sig_geterror(sigs[4]) == DKIM_SIGERROR_KEYTYPEUNKNOWN);
 	assert(dkim_sig_geterror(sigs[5]) == DKIM_SIGERROR_DNSSYNTAX);
 	assert(dkim_sig_geterror(sigs[6]) == DKIM_SIGERROR_KEYREVOKED);
-	assert(dkim_sig_geterror(sigs[7]) == DKIM_SIGERROR_UNKNOWN);
+	assert(dkim_sig_geterror(sigs[7]) == DKIM_SIGERROR_KEYDECODE);
 
 	status = dkim_free(dkim);
 	assert(status == DKIM_STAT_OK);
