@@ -6,7 +6,7 @@
 #ifdef _FFR_VBR
 
 #ifndef lint
-static char vbr_c_id[] = "@(#)$Id: vbr.c,v 1.11 2009/02/07 01:01:33 msk Exp $";
+static char vbr_c_id[] = "@(#)$Id: vbr.c,v 1.12 2009/02/18 23:44:14 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -155,7 +155,7 @@ vbr_verror(VBR *vbr, const char *format, va_list va)
 {
 	int flen;
 	int saverr;
-	char *new;
+	u_char *new;
 
 	assert(vbr != NULL);
 	assert(format != NULL);
